<?php
$this->js_css->parse_css('rtgrid_video/css/main.css');
$this->js_css->parse_js('rtgrid_video/js/main.js');
?>
<div class="input-append control-group">
    <input class="span4 video_link" type="text" placeholder="<?= $this->lang->line('Enter youtube share link') ?>">
    <button class="btn video_btn_add" type="button"><i class="icon-plus"></i><?= $this->lang->line('Add') ?></button>
</div>
<ul class="video_items"></ul>

<div style="display: none" class="video_tab_etalon_item">
    <div class="video_item">
        <iframe width="200" height="200" src="https://www.youtube.com/embed/LINK" frameborder="0" allowfullscreen></iframe>
        <a href="#" class="video_btn_remove" data-id="https://youtu.be/LINK"><i class="icon-remove"></i><?= $this->lang->line('Remove') ?></a>
    </div>
</div>