.video_items{
    float: left;
    width: 100%;
    margin-top: 20px;
}
.video_items li{
    float: left;
    width: 200px;
    margin: 0 10px 25px 0;
}
.video_item{
    text-align: center;
}
.video_item .video_btn_remove{
    display: inline-block;
}