$(function () {
    var video_tab = {
        'videoItems': $('.video_items'),
        'refresh': function () {
            $('.video_btn_remove').click(function () {
                var el = $(this).parent().parent();
                $.post('', {'removeItem': $(this).attr('data-id')}, function (rs) {
                    if (rs.success) {
                        el.remove();
                    }
                });

                return false;
            });
        },
        'addItem': function (link) {
            if (link) {
                var template = '<li>' + $('.video_tab_etalon_item').html() + '</li>';
                video_tab.videoItems.append(template.replace(/LINK/g, link.replace('https://youtu.be/', '')));
            }
        },
        'loadItems': function () {
            $.post('', {'getItems': 'all'}, function (rs) {
                $.each(rs, function (k, v) {
                    video_tab.addItem(v);
                });
                video_tab.refresh();
            });
        },
        'saveItem': function (link) {
            $.post('', {'saveItem': link}, function (rs) {
                if (rs.success) {
                    video_tab.addItem(link);
                    video_tab.refresh();
                }
            });
        }
    };

    $('.video_btn_add').click(function () {
        var elParent = $(this).parent();
        var video_link = elParent.find('.video_link');
        var link = video_link.val();
        if (link.indexOf('youtu.be') !== -1) {
            elParent.removeClass('error');
            video_tab.saveItem(link);
            video_link.val('');
        } else {
            elParent.addClass('error');
        }

        return false;
    });

    video_tab.loadItems();
});