CREATE TABLE IF NOT EXISTS `TABLE_NAME` ( 
`id_TABLE_NAME` int(11) NOT NULL AUTO_INCREMENT,
`PARENT_FIELD` int(11),
`link` varchar(255) CHARACTER SET utf8,
PRIMARY KEY (`id_TABLE_NAME`) 
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
